/**
* This source code is an example that shows how to use the method Read4DigitalInputs
* The algorithm is the following:
* - Open board (via index or identifier - see the Utils.cpp file)
* - Call the method Read4DigitalInputs
* - Close the board
**/
#include "stdafx.h"

#define VALUE_CHANNEL_0(x)	( x & 0x1 )
#define VALUE_CHANNEL_1(x)	( (x >> 1) & 0x1 )
#define VALUE_CHANNEL_2(x)	( (x >> 2) & 0x1 )
#define VALUE_CHANNEL_3(x)	( (x >> 3) & 0x1 )

/**
* Entry point
**/
int _tmain( int /*argc*/, _TCHAR* /*argv[]*/ )
{
	INT returnValue = 0;
	HANDLE	boardHandle = NULL;
	BYTE channelsValue = 0;

	/* call the util method to open a board */
	returnValue = OpenBoard(&boardHandle);
	if (returnValue != 0)
	{
		printf("Error while opening the board : %d \n", (int) returnValue);
		_getch();
		return -1;
	}

	/* display some useful informations */
	printf("* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * \n");
	printf("* Read 4 digital inputs sample. \n");
	printf("* Read the 4 digital inputs of the board and display their status. \n");
	printf("* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * \n\n");

	printf("\n Press any key to exit the sample ...\n");
	printf("____________________________________________________________\n");
	printf("|Channel 0 \t |Channel 1 \t |Channel 2 \t |Channel 3|\n");
	do
	{
		/* read the value of the selected channel */
		returnValue = i_PCIe3021_Read4DigitalInputs(boardHandle, &channelsValue);
		if (returnValue != 0)
		{
			printf("Error while reading 4 digital inputs : %d \n", returnValue);
			/* close the board and return */
			i_PCIe3021_CloseBoard(boardHandle);
			return -1;
		}

		/* print the channel value */
		printf("|%d \t\t |%d \t\t |%d \t\t |%d        |\t",
			VALUE_CHANNEL_0(channelsValue),
			VALUE_CHANNEL_1(channelsValue),
			VALUE_CHANNEL_2(channelsValue),
			VALUE_CHANNEL_3(channelsValue));
		
		/* show that something is running */
		DisplayRunningStatus();

		Sleep(50);
	}
	while ( !_kbhit() );
	
	/* close the board */
	returnValue = i_PCIe3021_CloseBoard(boardHandle);
	if (returnValue != 0)
	{
		printf("Error while closing board : %d \n", (int)returnValue);
		_getch();
		return -1;
	}

	/* success */
	return 0;
}