/**
* This source code is an example about how to use the Set4DigitalOutputsFunction
* It also uses the output memory and the GetDigitalOutputStatus function
**/
#include "stdafx.h"

#define VALUE_CHANNEL_0(x)	( x & 0x1 )
#define VALUE_CHANNEL_1(x)	( (x >> 1) & 0x1 )
#define VALUE_CHANNEL_2(x)	( (x >> 2) & 0x1 )
#define VALUE_CHANNEL_3(x)	( (x >> 3) & 0x1 )

/**
* Function that enables to print the current status of the output
* @param boardHandle A handle to a device
* @return 0 on success, != 0 on error
**/
static INT PrintOutputStatus( HANDLE boardHandle )
{
	INT returnValue = 0;
	BYTE outputStatus = 0;

	returnValue = i_PCIe3021_Get4DigitalOutputsStatus( boardHandle, &outputStatus );
	if ( returnValue != 0 )
	{
		printf("Error while getting 4 digital outputs status : %d \n", returnValue );
		return -1;
	}

	printf("\nCurrent output status :\n");
	printf("____________________________________________________________\n");
	printf("|Channel 0 \t |Channel 1 \t |Channel 2 \t |Channel 3|\n");
	/* print the outputs status */
	printf("|%d \t\t |%d \t\t |%d \t\t |%d        |\n",
		VALUE_CHANNEL_0(outputStatus),
		VALUE_CHANNEL_1(outputStatus),
		VALUE_CHANNEL_2(outputStatus),
		VALUE_CHANNEL_3(outputStatus));

	return 0;
}

/**
* Entry point
**/
int _tmain( int /*argc*/, _TCHAR* /*argv[]*/ )
{
	INT returnValue = 0;
	HANDLE	boardHandle = NULL;
	int outputMemoryUsed = 0;
	int choice = 0;
	ULONG readValue = 0;

	/* call the util method to open a board */
	returnValue = OpenBoard(&boardHandle);
	if (returnValue != 0)
	{
		printf("Error while opening the board : %d \n", (int) returnValue);
		_getch();
		return -1;
	}

	/* display some useful informations */
	printf("* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * \n");
	printf("* Set 4 digital outputs sample. \n");
	printf("* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * \n\n");

	/* digital output memory */
	ReadUlong("Do you want to use output memory ? (0: No, 1: Yes) ",0,1,&readValue);
	outputMemoryUsed = (int) readValue;

	/* set the digital output memory */
	if ( outputMemoryUsed == 1 )
	{
		returnValue = i_PCIe3021_SetDigitalOutputMemoryOn(boardHandle);
		if ( returnValue != 0 )
		{
			printf("Error while setting digital output memory to on : %d \n", (int) returnValue);
			i_PCIe3021_CloseBoard(boardHandle);
			_getch();
			return -1;
		}
	}
	/* reset the digital output memory */
	else if ( outputMemoryUsed == 0 )
	{
		returnValue = i_PCIe3021_SetDigitalOutputMemoryOff(boardHandle);
		if ( returnValue != 0 )
		{
			printf("Error while setting digital output memory to off : %d \n", (int) returnValue);
			i_PCIe3021_CloseBoard(boardHandle);
			_getch();
			return -1;
		}
	}

	/* print the current output status */
	returnValue = PrintOutputStatus( boardHandle );
	if ( returnValue != 0 )
	{
		i_PCIe3021_CloseBoard(boardHandle);
		_getch();
		return -1;
	}

	/* endless loop */
	do
	{
		BYTE channelMask = 0;
		int state = 0;

		/* get the channel to set */
		ReadUlong("Give a mask of channel to set (Bit 0 for ch. 0, bit 1 ch. 1, ...) : ",0,0xF,&readValue);
		channelMask = (BYTE)readValue;

		/* get the state */
		ReadUlong("Status to set for the mask. (0: Off, 1: On) ",0,1,&readValue);
		state = (int)readValue;

		/* set the state to ON*/
		if ( state == 1 )
		{
			/* set the output to on */
			returnValue = i_PCIe3021_Set4DigitalOutputsOn( boardHandle, channelMask );
			if ( returnValue != 0 )
			{
				printf("Error while setting 4 digital outputs %x to on : %d \n",channelMask, (int) returnValue);
				i_PCIe3021_CloseBoard(boardHandle);
				_getch();
				return -1;	
			}
		}
		/* set the state to OFF*/
		else if ( state == 0 )
		{
			/* check if digital memory is set or not */
			if ( outputMemoryUsed == 0 )
			{
				printf("You cannot set a channel to false since the digital output memory is not enabled \n");
				continue;
			}

			/* set the output to off */
			returnValue = i_PCIe3021_Set4DigitalOutputsOff( boardHandle, (BYTE) channelMask );
			if ( returnValue != 0 )
			{
				printf("Error while setting 4 digital outputs %x to off : %d \n",channelMask, (int) returnValue);
				i_PCIe3021_CloseBoard(boardHandle);
				_getch();
				return -1;	
			}
		}

		/* print the current output status */
		returnValue = PrintOutputStatus( boardHandle );
		if ( returnValue != 0 )
		{
			_getch();
			return -1;
		}

		/* continue ? */
		do
		{
			printf("Do you want to set other channels ? (0: Yes, 1: No) ");
			_flushall();
			scanf_s("%d",&choice);
		}	while ( (choice != 0) && (choice != 1) );

	} while (choice != 1 );

	return 0;
}

