/**
* This sample demonstrate how to use the trigger functionnality of the timer
**/

#include "stdafx.h"

/**
* Entry point
**/
int _tmain( int /*argc*/, _TCHAR* /*argv[]*/ )
{
	INT returnValue = 0;
	HANDLE	boardHandle = NULL;
	ULONG readValue = 0;

	/* call the util method to open a board */
	returnValue = OpenBoard(&boardHandle);
	if (returnValue != 0)
	{
		printf("Error while opening the board : %d \n", (int) returnValue);
		_getch();
		return -1;
	}

	/* display some useful informations */
	printf("* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * \n");
	printf("* Timer with trigger sample. \n");
	printf("* The sequence is : \n");
	printf("* This sample uses a timer with output disabled, mode 2, \n");
	printf("* time base in millisecond and a reload value of 5000 ms. \n");
	printf("* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * \n\n");

	/* start the timer */
	returnValue = i_PCIe3021_InitAndStartTimer( boardHandle,
		PCIE3021_TIMER_MODE_2,				/* mode 2*/
		PCIE3021_TIME_BASE_MILLISECONDS,	/* time base millisecond */
		0,									/* output disabled */
		0,									/* interrupt disabled */
		5000);								/* reload value */

	/* endless loop */
	printf("\nTimer is started. Press 't' to trigger the timer and 'ESC' to exit this sample.\n");
	for (;;)
	{
		BYTE status = 0;
		BYTE triggerStatus = 0;
		WORD value = 0;

		/* get the timer status */
		returnValue = i_PCIe3021_ReadTimerStatus(boardHandle,
			&status,
			&triggerStatus,
			&value);
		if ( returnValue != 0)
		{
			printf("Error while reading timer's status : %d \n", returnValue);
			/* stop the timer and exit */
			i_PCIe3021_StopTimer(boardHandle);
			i_PCIe3021_CloseBoard(boardHandle);
			_getch();
			return -1;
		}

		/* display the value */
		printf("Value : %d. Trigger : %d \t\t", (int)value, (int) triggerStatus );

		/* check if a key was hit */
		if ( _kbhit() )
		{
			switch ( _getch() )
			{
				/* t or T */
				case 116:
				case 84:
					/* trigger the timer */
					returnValue = i_PCIe3021_TriggerTimer( boardHandle);
					if ( returnValue != 0 )
					{
						printf("Error while triggering timer : %d \n", returnValue);
						/* stop the timer and exit */
						i_PCIe3021_StopTimer(boardHandle);
						i_PCIe3021_CloseBoard(boardHandle);
						_getch();
						return -1;
					}
					break;
				/* esc */
				case 27:
					/* stop the timer */
					returnValue = i_PCIe3021_StopTimer(boardHandle);
					if ( returnValue != 0 )
					{
						printf("Error while stopping the timer logic : %d \n", (int) returnValue);
						i_PCIe3021_CloseBoard(boardHandle);
						_getch();
						return -1;
					}
					/* success */
					i_PCIe3021_CloseBoard(boardHandle);
					return 0;
			}
		}
		Sleep(100);
		DisplayRunningStatus();
	}
}

