UNIT PCIe3021;

INTERFACE

CONST
//=========================================
//Digital input/output related :
//=========================================
PCIE3021_DIGITAL_INPUT_NUMBER			    = 4;
PCIE3021_DIGITAL_OUTPUT_NUMBER			    = 4;
//=========================================
//Timer mode :
//=========================================
PCIE3021_TIMER_MODE_2				        = 0;
PCIE3021_TIMER_MODE_3					    = 1;
//=========================================
//Delay mode (all other values > 0 are actual delay values) :
//=========================================
PCIE3021_NO_DELAY						    = 0;
//=========================================
//Analog acquisition cycle (all other values > 0 are actual number of sequences) :
//=========================================
PCIE3021_CONTINUOUS_CYCLE				    = 0;
//=========================================
//Time base :
//=========================================
PCIE3021_TIME_BASE_MICROSECONDS			    = 0;
PCIE3021_TIME_BASE_MILLISECONDS			    = 1;
PCIE3021_TIME_BASE_SECONDS				    = 2;
//=========================================
//Output mode :
//=========================================
PCIE3021_OUTPUT_DISABLED				    = 0;
PCIE3021_OUTPUT_ENABLED					    = 1;
PCIE3021_OUTPUT_INVERTED				    = 2;
//=========================================
//External trigger mode :
//=========================================
PCIE3021_EXT_TRIGGER_DISABLED			    = $0;
PCIE3021_EXT_TRIGGER_ENABLED_LOW		    = $1;
PCIE3021_EXT_TRIGGER_ENABLED_HIGH		    = $2;
PCIE3021_EXT_TRIGGER_ENABLED_BOTH		    = $3;
//=========================================
// Software trigger mode :
//=========================================
PCIE3021_SOFT_TRIGGER_DISABLED			    = $0;
PCIE3021_SOFT_TRIGGER_ENABLED			    = $1;
//=========================================
//Trigger types :
//=========================================
PCIE3021_TRIGGER_ONE_SHOT				    = $0;
PCIE3021_TRIGGER_SEQUENCE_TRIGGER		    = $8;
PCIE3021_TRIGGER_SINGLE_SEQUENCE		    = $C;
//=========================================
//Analog output mode :
//=========================================
PCIE3021_OUTPUT_MODE_UNIPOLAR			    = 0;
PCIE3021_OUTPUT_MODE_BIPOLAR			    = 1;
//=========================================
//Analog input modes :
//=========================================
PCIE3021_INPUT_MODE_UNDEFINED			    = 0;
PCIE3021_INPUT_MODE_SINGLE_ENDED		    = 1;
PCIE3021_INPUT_MODE_DIFFERENTIAL		    = 2;
//=========================================
//Gain values :
//=========================================
PCIE3021_GAIN_1							    = 0;
PCIE3021_GAIN_2							    = 1;
PCIE3021_GAIN_5							    = 2;
PCIE3021_GAIN_10						    = 3;

TYPE

PPointer      = ^Pointer;

	
FUNCTION   i_PCIe3021_GetNumberOfBoards (var pb_NbrOfBoards : Byte): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_GetBoardInformation (b_BoardIndex : Byte;
									      dw_IdentifierStringSize : LongWord;
									      pc_Identifier : PAnsiChar;
									      var	pdw_UINumber : LongWord;
								          var   pdw_DeviceNumber : LongWord;
								          var   pdw_BusNumber : LongWord;
									      var	pdw_BaseAddress0 : LongWord;
									      var	pdw_BaseAddress1 : LongWord;
									      var	pdw_BaseAddress2 : LongWord;
									      var	pdw_BaseAddress3 : LongWord;
									      var   pb_Interrupt : Byte ): Smallint;FAR;STDCALL;
								   
FUNCTION   i_PCIe3021_OpenBoardViaIndex (b_BoardIndex : Byte; var ph_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_OpenBoardViaIdentifier (pc_Identifier : PCHAR; var ph_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;
										
FUNCTION   i_PCIe3021_CloseBoard (h_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_GetDLLVersion (var pdw_Version : LongWord): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_GetDeviceDriverVersion(h_DeviceHandle : THANDLE; var pdw_Version : LongWord): Smallint;FAR;STDCALL;



FUNCTION   i_PCIe3021_SetBoardIntRoutine (h_DeviceHandle : THANDLE; v_FunctionName : Pointer): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_ResetBoardIntRoutine (h_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;



FUNCTION   i_PCIe3021_Read1DigitalInput (h_DeviceHandle : THANDLE; b_Channel : Byte; var pb_Value : Byte): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_Read4DigitalInputs (h_DeviceHandle : THANDLE; var pb_Value : Byte): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_Set1DigitalOutputOn (h_DeviceHandle : THANDLE; b_Channel : Byte): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_Set1DigitalOutputOff (h_DeviceHandle : THANDLE; b_Channel : Byte): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_Set4DigitalOutputsOn (h_DeviceHandle : THANDLE; b_Mask : Byte): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_Set4DigitalOutputsOff (h_DeviceHandle : THANDLE; b_Mask : Byte): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_SetDigitalOutputMemoryOn (h_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_SetDigitalOutputMemoryOff (h_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_Get1DigitalOutputStatus (h_DeviceHandle : THANDLE; b_Channel : Byte; var pb_OutputsStatus : Byte): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_Get4DigitalOutputsStatus (h_DeviceHandle : THANDLE; var	pb_OutputsStatus : Byte): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_InitAndStartTimer (h_DeviceHandle : THANDLE;
										b_TimerMode : Byte;
										b_TimeBase : Byte;
										b_OutputMode : Byte;
										b_InterruptEnabled : Byte;
										w_ReloadValue : Word): Smallint;FAR;STDCALL;
													  
FUNCTION   i_PCIe3021_StopTimer(h_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_ReadTimerStatus (h_DeviceHandle : THANDLE;
								        var pb_TimerStatus : Byte;
										var pb_SoftwareTriggerStatus : Byte;
								        var pw_TimerValue: Word ): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_ReadTimerValue  (h_DeviceHandle : THANDLE;
										var pw_TimerValue: Word ): Smallint;FAR;STDCALL;
										
FUNCTION   i_PCIe3021_TriggerTimer(h_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;

						
FUNCTION   i_PCIe3021_SetAnalogInputMode(h_DeviceHandle : THANDLE; b_InputMode : Byte): Smallint;FAR;STDCALL;
 
FUNCTION   i_PCIe3021_GetAnalogInputMode(h_DeviceHandle : THANDLE; var pb_InputMode : Byte): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_InitAndStartAnalogInputSequenceEx(h_DeviceHandle : THANDLE;
													 dw_SequenceCount : LongWord;
													 dw_SequenceBeforeInterrupt : LongWord;
													 b_ChannelCount : Byte;
													 var pb_Channel : Byte;
													 var pb_Gain : Byte;
													 var pb_Polarity : Byte;
													 dw_ConvertingTime : LongWord;
													 dw_DelayTime : LongWord;
													 b_SoftTriggerMode : Byte;
													 b_ExtTriggerMode : Byte;
													 dw_SequenceTriggerCount : LongWord;
													 dw_HardwareTriggerCount : LongWord): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_InitAndStartAnalogInputSequence(h_DeviceHandle : THANDLE;
													 dw_SequenceCount : LongWord;
													 dw_SequenceBeforeInterrupt : LongWord;
													 b_ChannelCount : Byte;
													 var pb_Channel : Byte;
													 var pb_Gain : Byte;
													 var pb_Polarity : Byte;
													 dw_ConvertingTime : LongWord;
													 dw_DelayTime : LongWord;
													 b_SoftTriggerMode : Byte;
													 b_ExtTriggerMode : Byte;
													 dw_SequenceTriggerCount: LongWord): Smallint;FAR;STDCALL;
													 
FUNCTION   i_PCIe3021_ReadMoreAnalogInputs (h_DeviceHandle : THANDLE;
										   b_ChannelCount : Byte;
										   var pb_Channel : Byte;
										   var pb_Gain : Byte;
										   var pb_Polarity : Byte;
										   dw_ConvertingTime : LongWord;
										   b_InterruptFlag : Byte;
									       b_SoftTriggerMode : Byte;
									       b_ExtTriggerMode : Byte;
									       var pw_ChannelValue : Word): Smallint;FAR;STDCALL;
			   
FUNCTION   i_PCIe3021_Read1AnalogInput (h_DeviceHandle : THANDLE;
								       b_Channel : Byte;
								       b_Gain : Byte;
								       b_Polarity : Byte;
								       dw_ConvertingTime : LongWord;
								       b_InterruptFlag : Byte;
								       b_SoftTriggerMode : Byte;
								       b_ExtTriggerMode : Byte;
								       var pw_ChannelValue : Word): Smallint;FAR;STDCALL;
									   
FUNCTION   i_PCIe3021_InitAndStartAutoRefreshAcquisition(h_DeviceHandle : THANDLE;
								                        b_ChannelCount : Byte;
													    var pb_Channel : Byte;
								                        var pb_Gain : Byte;
								                        var pb_Polarity : Byte;
								                        dw_ConvertingTime : LongWord;
								                        ppdw_Channels : PPointer): Smallint;FAR;STDCALL;
												
FUNCTION   i_PCIe3021_StopAnalogAcquisition (h_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_TriggerAnalogAcquisition (h_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;

FUNCTION   i_PCIe3021_GetAnalogInputChannelsNbr (h_DeviceHandle : THANDLE; var pb_NumberOfInputChannels : Byte): Smallint;FAR;STDCALL;

FUNCTION 	l_PCIe3021_ReadSequenceData(h_DeviceHandle : THANDLE; size : Cardinal; var data : Word): LongInt;FAR;STDCALL;  // size : LongWord



	
IMPLEMENTATION

FUNCTION   i_PCIe3021_GetNumberOfBoards (var pb_NbrOfBoards : Byte): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_GetBoardInformation(b_BoardIndex : Byte;
                                          dw_IdentifierStringSize : LongWord;
                                          pc_Identifier          : PAnsiChar;
                                          var	pdw_UINumber       : LongWord;
                                          var   pdw_DeviceNumber : LongWord;
                                          var   pdw_BusNumber : LongWord;
                                          var	pdw_BaseAddress0 : LongWord;
                                          var	pdw_BaseAddress1 : LongWord;
                                          var	pdw_BaseAddress2 : LongWord;
                                          var	pdw_BaseAddress3 : LongWord;
                                          var   pb_Interrupt : Byte ): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';
								   
FUNCTION   i_PCIe3021_OpenBoardViaIndex (b_BoardIndex : Byte; var ph_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_OpenBoardViaIdentifier (pc_Identifier : PCHAR; var ph_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';
										
FUNCTION   i_PCIe3021_CloseBoard (h_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_GetDLLVersion (var pdw_Version : LongWord): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_GetDeviceDriverVersion(h_DeviceHandle : THANDLE; var pdw_Version : LongWord): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_SetBoardIntRoutine (h_DeviceHandle : THANDLE; v_FunctionName : Pointer): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_ResetBoardIntRoutine (h_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';


FUNCTION   i_PCIe3021_Read1DigitalInput (h_DeviceHandle : THANDLE; b_Channel : Byte; var pb_Value : Byte): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_Read4DigitalInputs (h_DeviceHandle : THANDLE; var pb_Value : Byte): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_Set1DigitalOutputOn (h_DeviceHandle : THANDLE; b_Channel : Byte): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_Set1DigitalOutputOff (h_DeviceHandle : THANDLE; b_Channel : Byte): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_Set4DigitalOutputsOn (h_DeviceHandle : THANDLE; b_Mask : Byte): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_Set4DigitalOutputsOff (h_DeviceHandle : THANDLE; b_Mask : Byte): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_SetDigitalOutputMemoryOn (h_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_SetDigitalOutputMemoryOff (h_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_Get1DigitalOutputStatus (h_DeviceHandle : THANDLE; b_Channel : Byte; var pb_OutputsStatus : Byte): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_Get4DigitalOutputsStatus (h_DeviceHandle : THANDLE; var	pb_OutputsStatus : Byte): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';


FUNCTION   i_PCIe3021_InitAndStartTimer (h_DeviceHandle : THANDLE;
										b_TimerMode : Byte;
										b_TimeBase : Byte;
										b_OutputMode : Byte;
										b_InterruptEnabled : Byte;
										w_ReloadValue : Word): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_StopTimer(h_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_ReadTimerStatus (h_DeviceHandle : THANDLE;
								        var pb_TimerStatus : Byte;
										var pb_SoftwareTriggerStatus : Byte;
								        var pw_TimerValue: Word ): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_ReadTimerValue  (h_DeviceHandle : THANDLE; var pw_TimerValue: Word ): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_TriggerTimer(h_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_SetAnalogInputMode(h_DeviceHandle : THANDLE; b_InputMode : Byte): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';
 
FUNCTION   i_PCIe3021_GetAnalogInputMode(h_DeviceHandle : THANDLE; var pb_InputMode : Byte): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';


FUNCTION   i_PCIe3021_InitAndStartAnalogInputSequenceEx(h_DeviceHandle : THANDLE;
													 dw_SequenceCount : LongWord;
													 dw_SequenceBeforeInterrupt : LongWord;
													 b_ChannelCount : Byte;
													 var pb_Channel : Byte;
													 var pb_Gain : Byte;
													 var pb_Polarity : Byte;
													 dw_ConvertingTime : LongWord;
													 dw_DelayTime : LongWord;
													 b_SoftTriggerMode : Byte;
													 b_ExtTriggerMode : Byte;
													 dw_SequenceTriggerCount : LongWord;
													 dw_HardwareTriggerCount : LongWord): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_InitAndStartAnalogInputSequence(h_DeviceHandle : THANDLE;
													 dw_SequenceCount : LongWord;
													 dw_SequenceBeforeInterrupt : LongWord;
													 b_ChannelCount : Byte;
													 var pb_Channel : Byte;
													 var pb_Gain : Byte;
													 var pb_Polarity : Byte;
													 dw_ConvertingTime : LongWord;
													 dw_DelayTime : LongWord;
													 b_SoftTriggerMode : Byte;
													 b_ExtTriggerMode : Byte;
													 dw_SequenceTriggerCount: LongWord): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';
													 
FUNCTION   i_PCIe3021_ReadMoreAnalogInputs (h_DeviceHandle : THANDLE;
										   b_ChannelCount : Byte;
										   var pb_Channel : Byte;
										   var pb_Gain : Byte;
										   var pb_Polarity : Byte;
										   dw_ConvertingTime : LongWord;
										   b_InterruptFlag : Byte;
									       b_SoftTriggerMode : Byte;
									       b_ExtTriggerMode : Byte;
									       var pw_ChannelValue : Word): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_Read1AnalogInput (h_DeviceHandle : THANDLE;
								       b_Channel : Byte;
								       b_Gain : Byte;
								       b_Polarity : Byte;
								       dw_ConvertingTime : LongWord;
								       b_InterruptFlag : Byte;
								       b_SoftTriggerMode : Byte;
								       b_ExtTriggerMode : Byte;
								       var pw_ChannelValue : Word): Smallint;FAR;STDCALL;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_InitAndStartAutoRefreshAcquisition(h_DeviceHandle : THANDLE;
								                        b_ChannelCount : Byte;
													    var pb_Channel : Byte;
								                        var pb_Gain : Byte;
								                        var pb_Polarity : Byte;
								                        dw_ConvertingTime : LongWord;
								                        ppdw_Channels : PPointer): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';
	
FUNCTION   i_PCIe3021_StopAnalogAcquisition (h_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION   i_PCIe3021_TriggerAnalogAcquisition (h_DeviceHandle : THANDLE): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION    i_PCIe3021_GetAnalogInputChannelsNbr (h_DeviceHandle : THANDLE; var pb_NumberOfInputChannels : Byte): Smallint;FAR;STDCALL;External 'PCIe3021.DLL';

FUNCTION 	l_PCIe3021_ReadSequenceData(h_DeviceHandle : THANDLE; size : Cardinal;  var data : Word): LongInt;FAR;STDCALL;External 'PCIe3021.DLL';  // size : LongWord

END.